### Encoding: UTF-8

### Name: ppca
### Title: Phylogenetic principal component analysis
### Aliases: ppca print.ppca summary.ppca scatter.ppca screeplot.ppca
###   plot.ppca
### Keywords: multivariate

### ** Examples

## build an look at data
data(maples)
tre <- read.tree(text=maples$tre)
x <- phylo4d(tre, maples$tab)
omar <- par("mar")
par(mar=rep(.1,4))
table.phylo4d(x, cex.lab=.5, cex.sym=.6, ratio=.1) # note NAs in last trait ('x')

## function to replace NA
f1 <- function(vec){
if(any(is.na(vec))){
m <- mean(vec, na.rm=TRUE)
vec[is.na(vec)] <- m
}
return(vec)
}

## compute a PCA
dat <- apply(maples$tab,2,f1) # replace NAs
x.noNA <- phylo4d(tre, as.data.frame(dat))
if(require(ade4)){
ppca1 <- ppca(x.noNA, scannf=FALSE, method="Abouheif")
ppca1

## some graphics
screeplot(ppca1)
scatter(ppca1, useLag=TRUE)
plot(ppca1, useLag=TRUE)

## most structured traits
a <- ppca1$c1[,1] # loadings on PC 1
names(a) <- row.names(ppca1$c1)
highContrib <- a[a< quantile(a,0.1) | a>quantile(a,0.9)]
datSel <- cbind.data.frame(dat[, names(highContrib)], ppca1$li)
temp <- phylo4d(tre, datSel)
table.phylo4d(temp) # plot of most structured traits

## phylogenetic autocorrelation tests for these traits
prox <- proxTips(tre, method="Abouheif")
gearymoran(prox, dat[, names(highContrib)]) # one test per trait
}



